package PHX;
use Digest::MD5;
use Sys::Hostname;
use Sys::Syslog qw(:standard :macros);
use DateTime;
use IO::File;

my @gates = qw(templebar ishtar water brandenburg);
my $rhs   = "smsgate.fishsoupisgoodforyou.com";

sub canonize($) {
    my $a = shift;
    $a =~ s/^00/+/;
    $a =~ s/^0/+44/;
    $a =~ s/ /_/g;
    return $a;
}

sub email_to_addr($) {
 my $gate_id = shift;

 if ($gate_id==0) { 
	return 'k@therine.org';
  } else {
	return 'james@madingley.org';
  }
}

sub email_from_addr($$) {
    my ( $gate_id, $addr ) = @_;

    return $gates[$gate_id] . "." . canonize($addr) . "@" . $rhs;

}

sub store_mid_ref($$) {
    my ( $mid, $ref ) = @_;

    my $fn = sprintf "/var/spool/xibalba/mid-%d", $ref;

    my $fh = new IO::File $fn, "w";
    return unless defined $fh;
    $fh->print($mid);
    $fh->close;
    undef $fh;
}

sub store_parts_ref($$) {
    my ( $parts, $ref ) = @_;

    my $fn = sprintf "/var/spool/xibalba/parts-%d", $ref;

    my $fh = new IO::File $fn, "w";
    return unless defined $fh;
    $fh->print($parts);
    $fh->close;
    undef $fh;
}

sub mid_from_ref($) {
    my ($ref) = @_;

    my $fn = sprintf "/var/spool/xibalba/mid-%d", $ref;

    my $fh = new IO::File $fn, "r";
    return "" unless defined $fh;

    local $/;
    my $ret = $fh->getline;
    $fh->close;
    undef $fh;


    return $ret;
}

sub parts_from_ref($) {
    my ($ref) = @_;

    my $fn = sprintf "/var/spool/xibalba/parts-%d", $ref;

    my $fh = new IO::File $fn, "r";
    return "" unless defined $fh;

    local $/;
    my $ret = $fh->getline;
    $fh->close;
    undef $fh;

    return $ret;
}

my $pb = undef;

sub read_pb() {

    return if defined $pb;

    $pb = {};

    open PB, "</etc/xibalba/pb.txt";

    while (<PB>) {
        chomp;
        next unless /^\s*([0-9+]+)\s*:(.*)$/s;
        push @{ $pb->{ canonize($1) } }, $2;
    }

    close PB;
}

sub name_from_addr($) {
    my $n = canonize(shift);
    read_pb();

    if ( defined $pb->{$n} ) {
        return join( ", ", @{ $pb->{$n} } );
    }

    return "";
}

sub escape($) {
    my $chr = shift;
    return sprintf( "<%02X>", ord($chr) );
}

sub sanitize($) {
    my $sane = shift;
    $sane =~ s/([^+()a-zA-Z0-9])/escape($1)/ge;
    return $sane;
}

sub log_message($) {
    my $sane = sanitize(shift);
    syslog( LOG_ERR, $sane );
}

sub pretty_time($) {
    my $t = shift;
    return $t->strftime("%a, %d %b %Y %H:%M:%S %z");
}

1;
