#!/usr/bin/env perl 

BEGIN { push @INC, "/etc/xibalba"; }

use strict;
use Data::Dumper;
use Sys::Syslog qw(:standard :macros);
use Sys::Hostname;
use MIME::Lite;
use SMS;
use PHX;

my $gate_id = $ARGV[0];

my $gate = $PHX::gates[$gate_id];

openlog( "xibalba-recv-pdu.pl " + $gate, "pid", LOG_MAIL );

my $pdu = $ENV{PDU};

syslog( LOG_ERR,"PDU: ".$pdu);

my $a = SMS::hex_to_array($pdu);

my $q = SMS::parse( $a, undef );

my $msg = MIME::Lite->new( To => 'james@madingley.org', );

my $body = "";

if ( $q->{type_id} == SMS::MT_STATUS_REPORT ) {

    my $parts = PHX::parts_from_ref( $q->{reference} );
    my $mid = PHX::mid_from_ref( $q->{reference} );

    # if receiving succeeded wipe all traces
    if ($q->{status_id} == 0 ) {
	PHX::store_mid_ref( "", $q->{reference} )
    }

    $msg->replace( "Date" => PHX::pretty_time( $q->{dt_stamp}->{time} ) );
    $msg->replace(
        "From" => PHX::email_from_addr( $gate_id, $q->{originator}->{addr} ) );
    $msg->replace( "In-Reply-To" => $mid );
    $msg->replace( "References"  => $mid );
    $msg->replace( "Subject" => "Subject: SMS Status Report: "
          . $parts . " "
          . $q->{status} . " for "
          . $q->{originator}->{addr} . " "
          . PHX::name_from_addr( $q->{originator}->{addr} ) );

    $body .= "SMS Status Report:\n\n";
    $body .=
        "Dest ME address   : "
      . $q->{originator}->{addr} . " "
      . PHX::name_from_addr( $q->{originator}->{addr} ) . "\n";
    $body .=
      "Status            : " . $q->{status} . " (" . $q->{status_id} . ")\n";
    $body .=
      "Dest ME time stamp: "
      . PHX::pretty_time( $q->{dt_stamp}->{time} ) . "\n";
    $body .= "\n";
    $body .= "\n";
    $body .=
      "Status            : " . $q->{status} . " (" . $q->{status_id} . ")\n";
    $body .= "Dest ME address   : " . $q->{originator}->{addr} . "\n";
    $body .= "SMSC    address   : " . $q->{smsc}->{addr} . "\n";
    $body .= "Reporting host    : " . hostname . "\n";
    $body .=
      "Dest ME time stamp: "
      . PHX::pretty_time( $q->{dt_stamp}->{time} ) . "\n";
    $body .=
      "SMSC    time stamp: "
      . PHX::pretty_time( $q->{sc_stamp}->{time} ) . "\n";
    $body .=
      "Host    time stamp: " . PHX::pretty_time( DateTime->now() ) . "\n";
    $body .= "Reference         : " . $q->{reference} . "\n";
    $body .= "Part              : " . $parts . "\n";
    $body .=
      "Message-ID        : " . $mid . "\n";
    $body .= "\n";
    $body .= "\n";


}
elsif ( $q->{type_id} == SMS::MT_DELIVER ) {

    $msg->replace( "Date" => PHX::pretty_time( $q->{sc_stamp}->{time} ) );
    $msg->replace(
        "From" => PHX::email_from_addr( $gate_id, $q->{originator}->{addr} ) );
    $msg->replace( "Subject" => "Subject: SMS Received: "
          . $q->{status}
          . " from "
          . $q->{originator}->{addr} . " "
          . PHX::name_from_addr( $q->{originator}->{addr} ) );

    $body .= "SMS Deliver::\n\n";
    $body .=
        "Source ME address : "
      . $q->{originator}->{addr} . " "
      . PHX::name_from_addr( $q->{originator}->{addr} ) . "\n";
    if ( $q->{user_header} and $q->{user_header}->{concat} ) {
        $body .=
            "Concat Position   : "
          . $q->{user_header}->{concat_sequence} . "/"
          . $q->{user_header}->{concat_total} . "\n";
    }
    $body .= "Text              : " . $q->{user_data}->{text} . "\n";
    $body .= "\n";
    $body .= "\n";
    $body .= "Source ME address : " . $q->{originator}->{addr} . "\n";
    $body .= "SMSC    address   : " . $q->{smsc}->{addr} . "\n";
    $body .= "Reporting host    : " . hostname . "\n";
    $body .=
      "SMSC    time stamp: "
      . PHX::pretty_time( $q->{sc_stamp}->{time} ) . "\n";
    $body .=
      "Host    time stamp: " . PHX::pretty_time( DateTime->now() ) . "\n";
    $body .= "PID               : " . $q->{pid} . "\n";

    if ( $q->{user_header} and $q->{user_header}->{concat} ) {
        $body .=
            "Concat Position   : "
          . $q->{user_header}->{concat_sequence} . "/"
          . $q->{user_header}->{concat_total} . "\n";
        $body .=
          "Concat Reference  : " . $q->{user_header}->{concat_reference} . "\n";
    }

    $body .= "\n";
}

$body .= "PDU               : " . $pdu . "\n";
$body .= "\n";

$msg->data($body);

MIME::Lite->send( 'smtp', '127.0.0.1', Timeout => 60 );
$msg->send;

exit 0;
